//
//  ZMSCameraPosition.h
//  ZDCMaps
//
//  Created by zdc on 2014/12/08.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#ifndef ZDCMaps_ZMSCameraPosition_h
#define ZDCMaps_ZMSCameraPosition_h


#import <CoreLocation/CoreLocation.h>
#import <UIKit/UIKit.h>

/**
 * immutableなクラスでカメラのポジションなどのパラメータを
 * 管理する
 */
@interface ZMSCameraPosition : NSObject<NSCopying, NSMutableCopying>

/**
 *カメラ位置（緯度経度 度分秒）
 */
@property(nonatomic, readonly) CLLocationCoordinate2D target;

/** 
 *カメラレベル (1.0 - 21.0)
 */
@property(nonatomic, readonly) float zoom;

/**
 *軸方向 (時計回りに0-360度)
 */
@property(nonatomic, readonly) CLLocationDirection bearing;

/**
 * 視点角度 (0(地図平面に対して直角) - 30度 )
 */
@property(nonatomic, readonly) double viewingAngle;


/**
 * 初期化メソッド
 * カメラに設定可能のパラメータの値を明示的に設定することができる
 * 初期化メソッド
 * @param target CLLocationCoordinate2D 型の緯度経度座標
 * @param zoom ズームレベル
 * @param bearing 地図回転角度（Z軸回転[右手座標系]）
 * @param viewingAngle バードビュー回転角度 （X軸回転[右手座標系]）
 */
- (id)initWithTarget:(CLLocationCoordinate2D)target
                zoom:(float)zoom
             bearing:(CLLocationDirection)bearing
        viewingAngle:(double)viewingAngle;


/**
 * 任意の緯度経度座標とズームレベルの ZMSCameraPostion を生成する
 * 簡易ファクトリメソッド
 *
 * カメラの回転角度などのその他のパラメータはデフォルト値（0）が
 * 設定される
 * @param target CLLocationCoordinate2D 型の緯度経度座標
 * @param zoom ズームレベル
 */
+ (instancetype)cameraWithTarget:(CLLocationCoordinate2D)target zoom:(float)zoom;

/**
 * 任意の緯度と経度とズームレベルのZMSCameraPositionを生成する
 * 簡易ファクトリメソッド
 *
 * @param latitude CLLocationDegrees 型の緯度
 * @param longitude CLLocationDegrees 型の経度
 * @param zoom ズームレベル
 */
+ (instancetype)cameraWithLatitude:(CLLocationDegrees)latitude
                         longitude:(CLLocationDegrees)longitude
                              zoom:(float)zoom;

/**
 * 全てのカメラプロパティを設定する簡易ファクトリメソッド
 *
 * @param target CLLocationCoordinate2D 型の緯度経度座標
 * @param zoom ズームレベル
 * @param bearing 地図回転角度（Z軸回転[右手座標系]）
 * @param viewingAngle バードビュー回転角度 （X軸回転[右手座標系]）
 */
+ (instancetype)cameraWithTarget:(CLLocationCoordinate2D)target
                            zoom:(float)zoom
                          bering:(CLLocationDirection)bearing
                    viewingAngle:(double)viewingAngle;


/**
 * 緯度経度と全てのカメラプロパティを指定する簡易ファクトリメソッド
 * @param latitude 緯度
 * @param longitude 経度
 * @param bearing 地図回転角度（Z軸回転[右手座標系]）
 * @param zoom ズームレベル
 */
+ (instancetype)cameraWithLatitude:(CLLocationDegrees)latitude
                         longitude:(CLLocationDegrees)longitude
                            bering:(CLLocationDirection)bearing
                              zoom:(float)zoom;

@end
#endif
