//
//  ZMSCoordinateBounds.h
//  ZDCMaps
//
//  Created by zdc on 2014/12/08.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#ifndef ZDCMaps_ZMSCoordinateBounds_h
#define ZDCMaps_ZMSCoordinateBounds_h

#import <CoreLocation/CoreLocation.h>
#import "ZMSProjection.h"

@class ZMSPath;

/**
 * 緯度経度における矩形のバウンディングボックスオブジェクト
 */
@interface ZMSCoordinateBounds : NSObject

/**
 * バウンディングボックスの北東の角の座標
 */
@property(nonatomic, readonly) CLLocationCoordinate2D northEast;

/** 
 * バウンディングボックスの南西の角の座標
 */
@property(nonatomic, readonly) CLLocationCoordinate2D southWest;

/**
 * バウンディングボックスがどの点も含んでいない場合はNOを返却
 *
 * 例えば `[[ZMSCoordinateBounds alloc] init].valid == NO.` になります
 */
@property(nonatomic, readonly, getter=isValid) BOOL valid;

/**
 * 緯度経度の座標の2点（北東と南西）によって初期化したバウンディングボックスを作成
 *
 * バウンディングボックスの経度方向の指定が曖昧な場合、距離が短い方のバウンディングボックスが作成される
 */
- (nonnull id)initWithCoordinate:(CLLocationCoordinate2D)coord1 coordinate:(CLLocationCoordinate2D)coord2;

@end

#endif
