//
//  ZMSGroundOverlay.h
//  ZDCMaps
//
//  Created by zdc on 2016/02/12.
//  Copyright © 2016年 ZENRIN DataCom Co., LTD.. All rights reserved.
//


#import "ZMSOverlay.h"
#import <UIKit/UIKit.h>

@class ZMSCoordinateBounds;

/**
 * ZMSGroundOverlayは地図平面上に画像を貼り付けることできるオブジェクト。
 * マーカーとは異なり、画像を貼り付ける位置は緯度経度によって明示的に
 * 設定することができる。
 * ZMSGroundOverlayはカメラの位置によって見た目の大きさが異なる。
 */
@interface ZMSGroundOverlay : ZMSOverlay

/**
 * ZMSGroundOverlayの位置を表す
 * このプロパティを変更すると連動してboundsも移動する
 */
@property(nonatomic, assign) CLLocationCoordinate2D position;


/**
 * 画像を回転させるときの画像のアンカーポイントを設定する[0.0-1.0]
 * 画像の左上が原点
 * デフォルト値は(0.5,0.5)画像中心。
 */
@property(nonatomic, assign) CGPoint anchor;

/**
 * boundsに設定した領域に貼り付ける画像を設定する
 * このプロパティがnilの場合は何も表示されれない
 */
@property(nonatomic, strong) UIImage *icon;


/**
 * 回転角度
 * 軸方向 (時計回りに0-360度)
 */
@property(nonatomic, assign) CLLocationDirection bearing;


/**
 * 画像を地図上のどこの位置に描画するかを設定する
 *
 */
@property(nonatomic, strong) ZMSCoordinateBounds *bounds;


/**
 * ZMSGroundOverlayの簡易コンストラクタ
 * boundsと貼り付ける画像を設定できる
 * @param bounds バウンズ（左下・右上緯度経度）
 * @param icon バウンズに貼り付ける画像
 * @return ZMSGroundOverlay
 */
+ (instancetype)groundOverlayWithBounds:(ZMSCoordinateBounds *)bounds icon:(UIImage *)icon;

/**
 * ZMSGroundOverlayの簡易コンストラクタ
 * 指定された画像が指定された拡縮レベルで画像のサイズのディスプレイのサイズが合うように描画される
 * 描画位置はpositionとanchor位置によって決まる
 * @param position 画像のanchor位置の緯度経度
 * @param icon バウンズに貼り付ける画像
 * @param zoomLevel 指定されたズームレベルで画像が等倍で表示される
 * @return ZMSGroundOverlay
 */
+ (instancetype)groundOverlayWithPosition:(CLLocationCoordinate2D)position icon:(UIImage *)icon zoomLevel:(CGFloat) zoomLevel;

@end
