//
//  ZMSPoint.h
//  ZDCMaps
//
//  Created by zdc on 2016/03/02.
//  Copyright © 2016年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#import "ZMSOverlay.h"
#import <UIKit/UIKit.h>

/**
 * 地図上に描画する注記やアイコンを定義する
 */
@interface ZMSLabel : ZMSOverlay

/**
 * 注記を描画する緯度経度(度)
 */
@property(nonatomic, assign) CLLocationCoordinate2D anchor;

/**
 * 注記文字列
 */
@property(nonatomic, strong ) NSString * text;

/**
 * フォントサイズ
 * 1- 文字列の長さにより最大フォントサイズは異なる
 */
@property(nonatomic, assign) CGFloat textSize;

/**
 * 注記の文字色(RGBA)
 */
@property(nonatomic, strong) UIColor * textColor;

/**
 * 注記の文字背景色(RGBA)
 */
@property(nonatomic, strong) UIColor * backgroundColor;

/** 
 * 背景の矩形部分の枠線色
 */
@property(nonatomic, strong) UIColor * strokeColor;

/**
 * 背景の矩形部分の枠線の線幅
 */
@property(nonatomic, assign) CGFloat strokeWidth;

/**
 * 注記の縁取り色
 */
@property(nonatomic, strong) UIColor *edgeColor;

/**
 * 注記の縁取り幅
 */
@property(nonatomic, assign) CGFloat edgeWidth;

/**
 * 背景部分の角の丸み半径
 */
@property(nonatomic, assign) CGFloat cornerSize;

/**
 * 注記と背景部分のパディングサイズ
 */
@property(nonatomic, assign) CGPoint backgroundPadding;

/**
 * 注記・記号の回転角度(度) [-180:180]
 */
@property(nonatomic, assign) CGFloat bearing;

/**
 * アイコンに対する注記の描画位置
 * 0 : 記号と注記の中心揃え
 * 1 : 記号の右側
 * 2 : 記号の左側
 * 3 : 記号の上側
 * 4 : 記号の下側（デフォルト）
 */
@property(nonatomic, assign) NSInteger  textposition;

/**
 * 縦書き横書き
 * 0 : 横書き
 * 1 : 縦書き
 */
@property(nonatomic, assign) NSInteger textdirection;

/**
 * アイコン画像列(複数設定可能)
 */
@property(nonatomic, strong) NSMutableArray<UIImage *> *icons;

/**
 * 強制描画
 */
@property (nonatomic, assign) BOOL force;


/**
 * 簡易コンストラクタ
 * @param text 文字列
 * @param anchor 文字列の基準点の位置（緯度経度）
 * @return ZMSLabel
 */
+ (instancetype)textWithText:(NSString *)text Anchor:(CLLocationCoordinate2D )anchor;

@end
