//
//  ZMSMapView.h
//  ZMSMapView
//
//  Created by zdc on 2014/12/05.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#ifndef ZMSMapView_ZMSMapView_h
#define ZMSMapView_ZMSMapView_h

#import <UIKit/UIKit.h>
#import <CoreLocation/CoreLocation.h>
#import <GLKit/GLKit.h>

#import "ZMSUISettings.h"
#import "ZMSCoordinateBounds.h"

// 前方宣言
@class ZMSMapView;
@class ZMSCameraPosition;
@class ZMSCameraUpdate;
@class ZMSMarker;
@class ZMSProjection;
@class ZMSIndoorDisplay;
@class ZMSMapLayer;
@class ZMSOverlay;
@class ZMSPolygon;
@class ZMSPolyline;
@class ZMSPoint;
@class ZMSProjection;

/**
 * ZMSMapViewのイベント用delegate
 */
@protocol ZMSMapViewDelegate <NSObject>

@optional

/**
 * アニメーションやジェスチャや地図のカメラが変化する前にコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param gesture YESの場合、ユーザーによる操作
 */
- (void)mapView:(ZMSMapView *)mapView willMove:(BOOL)gesture;

/**
 * アニメーション中やジェスチャ中に繰り返しコールされる
 *
 * ただし、アニメーション中の全てのカメラ位置において呼ばれないが、アニメーションなどの最後のカメラ位置では必ずコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param position カメラの状況
 */
- (void)mapView:(ZMSMapView *)mapView didChangeCameraPosition:(ZMSCameraPosition *)position;

/**
 * カメラ移動が完了した後にアイドル状態とった際にコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param position カメラの状況
 */
- (void)mapView:(ZMSMapView *)mapView idleAtCameraPosition:(ZMSCameraPosition *)position;

/**
 * マーカーの描画位置を除いた任意の位置をタップした後にコールされる
 *
 * ただし、選択されているマーカーを非選択にする前にはコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param coordinate タップされた座標
 */
- (void)mapView:(ZMSMapView *)mapView didTapAtCoordinate:(CLLocationCoordinate2D)coordinate;

/**
 * 地図上の任意の位置を長押しするとコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param coordinate タップされた座標
 */
- (void)mapView:(ZMSMapView *)mapView didLongPressAtCoordinate:(CLLocationCoordinate2D)coordinate;

/**
 * マーカーがタップされるとコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param marker タップされたマーカー
 * @return YES:このdelegateがタップイベントを処理した場合
 * @return NO:delegateが実装していない場合
 */
- (BOOL)mapView:(ZMSMapView *)mapView didTapMarker:(ZMSMarker *)marker;

/**
 * マーカーが選択された状態になった時にコールされる
 *
 * このメソッドがオプションでカスタマイズされた情報ウィンドウを表示するためにUIViewを返却する
 *
 * @param mapView タップされたZMSMapView
 * @param marker タップされたマーカー
 * @return カスタム情報ウィンドウ
 */
- (nullable UIView *)mapView:(ZMSMapView *)mapView markerInfoWindow:(ZMSMarker *)marker;

/**
 * 情報ウィンドウがタップされるとコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param marker タップされたマーカー
 */
- (void)mapView:(ZMSMapView *)mapView didTapInfoWindowOfMarker:(ZMSMarker *)marker;

/**
 * 情報ウィンドウが長押しされるとコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param marker タップされたマーカー
 */
- (void)mapView:(ZMSMapView *)mapView didLongPressInfoWindowOfMarker:(ZMSMarker *)marker;

/**
 * ユーザーが作成したオブジェクトをタップした際にコールされる
 *
 * 引数にはタップされた位置がオブジェクトバウンズ内の全てのオブジェクトを返却する
 *
 * @param mapView タップされたZMSMapView
 * @param overlays タップされた位置に存在するオブジェクト
 */
- (void)mapView:(ZMSMapView *)mapView didTapOverlays:(NSArray *)overlays;

/**
 * 現在地ボタンが押された時にコールされる
 *
 * 位置情報の取得が有効か無効かに関わらず、ボタンを押すとコールされる
 *
 * @param mapView タップされたZMSMapView
 * @return YES:ユーザーが独自のイベント制御をおこなっている場合
 * @return NO:デフォルトの動作である地図中心を現在地とする場合
 */
- (BOOL)didTapMyLocationButtonForMapView:(ZMSMapView *)mapView;

#pragma mark - ZDCMaps original delegate

/**
 * 描画範囲外へ出た時にコールされる
 *
 * @param mapView タップされたZMSMapView
 * @param camera カメラの中心位置座標
 */
- (void)mapView:(ZMSMapView *)mapView onOutofArea:(ZMSCameraPosition *)camera;

/**
 * マップビュー内で発生したタッチイベント(TouchesBegan)をUIスレッド経由で中継する。
 *
 * @param mapView タップされたZMSMapView
 * @param touches タッチ情報
 * @param event UIEventオブジェクト
 */
- (void)mapView:(ZMSMapView *)mapView touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event;

/**
 * マップビュー内で発生したタッチイベント(TouchesMoved)をUIスレッド経由で中継する。
 *
 * @param mapView タップされたZMSMapView
 * @param touches タッチ情報
 * @param event UIEventオブジェクト
 */
- (void)mapView:(ZMSMapView *)mapView touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event;

/**
 * マップビュー内で発生したタッチイベント(TouchesEnded)をUIスレッド経由で中継する。
 *
 * @param mapView タップされたZMSMapView
 * @param touches タッチ情報
 * @param event UIEventオブジェクト
 */
- (void)mapView:(ZMSMapView *)mapView touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event;

/**
 * マップビュー内で発生したタッチイベント(TouchesCancelled)をUIスレッド経由で中継する。
 *
 * @param mapView タップされたZMSMapView
 * @param touches タッチ情報
 * @param event UIEventオブジェクト
 */
- (void)mapView:(ZMSMapView *)mapView touchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event;

// depreacated
- (void)mapView:(ZMSMapView *)mapView didTapOverlay:(ZMSOverlay *)overlay __attribute__ ((deprecated));

@end

/**
  * checkMapArea の処理結果。
  */
typedef NS_ENUM (NSUInteger, CheckMapAreaResult) {
	/**
	 * 処理失敗。
	 * checkMapArea が通信失敗等でエラーとなった場合に返る。
	 */
	Error,
	
	/**
	 * 地図を描画できないエリア。
	 * 指定したズームレベルの緯度経度に地図が描画できないときに返る。
	 */
	No,
	
	/**
	 * 地図を描画できるエリア。
	 * 指定したズームレベルの緯度経度に地図が描画できるときに返る。
	 */
	Yes
};


/**
 * ZMSMapViewはこのiOS向けのSDKのメインクラス
 * 地図に関連する全てのメソッドのエントリーポイントである
 *
 * 地図はここで定義されているファクトリメソッドでインスタンスが作成され
 * 生成される
 * 
 * ZMSMapViewはメインスレッドから読み込まれ、更新される
 * ほかのスレッドから呼び出されると、例外や未定義の動作となる
 */
@interface ZMSMapView : UIView <UIGestureRecognizerDelegate, UITableViewDataSource, UITableViewDelegate>

/**
 * ZMSMapViewのdelegate
 */
@property (nonatomic, weak) id <ZMSMapViewDelegate> delegate;


/**
 * 地図の表示位置などをコントロールするための
 * カメラ制御パラメータ
 */
@property (nonatomic, copy) ZMSCameraPosition *camera;


/**);
 * スクリーン座標と緯度経度座標の相互変換モジュール
 * このパラメータはカメラが動いた時に自動的に更新はさなれない
 * カメラが明示的にセットされたときや地図が生成された時、フレームが更新された時にのみ更新される
  */
@property (nonatomic, readonly) ZMSProjection *projection;

/**
 * 現在地マーカーと精度円を有効にする
 * デフォルトはNO
 */
@property (nonatomic, assign, getter=isMyLocationEnabled) BOOL myLocationEnabled;

/**
 * 現在地が有効な場合、現在地マーカーの描画位置を保持する
 * 現在地が無効な場合や現在地データが有効でない場合は、nilとなる
 */
@property (nonatomic, nullable, readonly) CLLocation *myLocation;

/**
 * 端末の向きに合わせて地図を回転する。
 * 現在位置に追従する。
 */
@property (nonatomic) BOOL headingUp;

/**
 * 選択マーカー
 * このプロパティを設定し、特定のマーカーを選択すると
 * 情報ウィンドウがマーカーの上部に表示される
 */
@property (nonatomic, strong) ZMSMarker *selectedMarker;



/**
 * 地図タイプを選択するためのプロパティ
 *
 */
@property (nonatomic, assign) NSString * mapType;


/**
 * 選択することが可能な地図タイプのリスト
 */
@property (nonatomic, strong) NSArray * mapTypeList;
/**
 * 最小の縮尺レベルをセットするプロパティ
 */
@property (nonatomic, assign, readonly) float minZoom;

/**
 * 最大の縮尺レベルをセットするプロパティ
 */
@property (nonatomic, assign, readonly) float maxZoom;




/*
 * 屋内地図の描画切り替えプロパティ
 */
@property (nonatomic, assign, getter = isIndoorEnabled) BOOL indoorEnabled;



/**
 * ZMSUISettingオブジェクトの取得用
 * ZMSUISettingは地図のユーザーインターフェースを制御する
 */
 @property (nonatomic, strong, readonly) ZMSUISettings *settings;

/*
 * ビューの描画領域を制御する
 * パディング領域を適応するとビューの周りのエッジ部分に
 * パディング領域が作成される。しかしUIは有効にならない
 */
@property (nonatomic, assign) UIEdgeInsets padding;

/**
 * 自作のZMSMapLayerのアクセサー
 */
@property (nonatomic, readonly, retain) ZMSMapLayer *layer;




/**
 * カメラの位置とフレームサイズからZMSMapViewインスタンスを作成し、返却する
 * @param frame ZMSMapViewのサイズ
 * @param camera カメラ位置情報など
 * @return ZMSMapView
 */
+ (instancetype)mapWithFrame:(CGRect)frame camera:(ZMSCameraPosition *)camera;


/**
 * カメラの位置とフレームサイズからZMSMapViewインスタンスを非同期に作成し、返却する
 * @param frame         ZMSMapViewのサイズ
 * @param camera        カメラ位置情報など
 * @param obj           呼び出し元オブジェクト
 * @param mapDidLoad    完了コールバック（ZMDMapView のインスタンスを引数として受け取る）
 * @note  エラー時には mapDidLoad に nil が渡される。
 */
+ (instancetype)mapWithFrame:(CGRect)frame camera:(ZMSCameraPosition *)camera target:(id)obj selector:(SEL)mapDidLoad;


/**
 * 地図に追加されている全てのマーカー・ポリライン・ポリゴン・画像を
 * クリアする。メインスレッドで実行すること。
 */
- (void)clear;

/**
 * minZoomとmaxZoomをセットする
 * このメソッドは最小値未満や最大値以上の場合は例外が発生する
 * NSRangeException
 * @param minZoom 最小ズームレベル
 * @param maxZoom 最大ズームレベル
 */
- (void)setMinZoom:(float)minZoom maxZoom:(float)maxZoom;


/**
 * updateによってカメラを変更する
 * カメラの移動はアニメーションではなく、
 * 瞬時に移動する
 * @param update 地図の更新パラメータ
 */
- (void)moveCamera:(ZMSCameraUpdate *)update;

/**
 * 引数のcameraPositionに従って、設定内容をアニメーションで反映する。
 * @param cameraPosition カメラ設定情報
 * @param duration アニメーション時間（秒）
 */
- (void)animateToCameraPosition:(ZMSCameraPosition*)cameraPosition Duration:(double)duration;
/**
 * 引数のlocationにカメラをアニメーション移動する。
 * @param location 移動目的地
 * @param duration アニメーション時間（秒）
*/
- (void)animateToLocation:(CLLocationCoordinate2D)location Duration:(double)duration;
/**
 * 引数のzoom値にカメラをズームアニメーションする。
 * @param zoom ズーム値
 * @param duration アニメーション時間（秒）
 */
- (void)animateToZoom:(float)zoom Duration:(double)duration;
/**
 * 引数のbearing値にカメラを回転アニメーションする。
 * @param bearing 方角値
 * @param duration アニメーション時間（秒）
 */
- (void)animateToBearing:(CLLocationDirection)bearing Duration:(double)duration;
/**
 * 引数のviewingAngle値にカメラをチルトアニメーションする。
 * @param viewingAngle チルト値
 * @param duration アニメーション時間（秒）
 */
- (void)animateToViewingAngle:(double)viewingAngle Duration:(double)duration;
/**
 * 引数のcameraUpdateに従って、設定内容をアニメーションで反映する。
 * @param cameraUpdate カメラ更新情報
 * @param duration アニメーション時間（秒）
 */
- (void)animateWithCameraUpdate:(ZMSCameraUpdate*)cameraUpdate Duration:(double)duration;


//MARK: - ZDC Original IF


/**
 * 現在地の設定を行う
 * @param coord 現在地の緯度経度
 */
- (void)setMyLocation:(CLLocation *)coord;

/**
 * カメラの移動範囲をバウンディングボックスで設定する
 * カメラ中心がバウンディングボックス内のみ移動可能となる
 * バウンディングボックスの左下・右上座標が同一の点の場合は
 * 描画範囲は無効となる
 * @param bbox 地図の描画領域バウンズ（緯度経度）
 */
- (void)setMovableRegion:(ZMSCoordinateBounds *)bbox;

/**
 * コンパスアイコンがタップされている時の背景部画像を設定する
 * 背景部分は地図回転に連動せず固定表示される
 * @param backgroundFocusImage コンパス背景画像
 */
- (void)setCompassBackgroundFocusImage:(nullable UIImage *)backgroundFocusImage;

/**
 * コンパスアイコンがタップされていない時の背景部画像を設定する
 * 背景部分は地図回転に連動せず固定表示される
 * @param backgroundImage コンパス背景画像
 */
- (void)setCompassBackgroundImage:(nullable UIImage *)backgroundImage;

/**
 * コンパスアイコンの針画像を設定する
 * 針画像は地図の回転にともない回転する
 * @param needleImage 針画像
 */
- (void)setCompassNeedleImage:(nullable UIImage *)needleImage;

/**
 * フォーカス時（タッチ時）の現在位置ボタン画像を設定する
 * @param focusImage 現在地ボタンの画像
 */
- (void)setgpsFocusImage:(nullable UIImage *)focusImage;

/**
 * 現在位置ボタン画像を設定する
 * @param onImage 現在ボタンの画像
 */
- (void)setgpsOnImage:(nullable UIImage *)onImage;

/**
  * 指定した緯度経度とズームレベルに地図が描画できるかを返す。
  * サーバー通信を行うため、ネットワーク状況によっては処理に時間がかかる。
  * @param coordinate   緯度経度
  * @param zoom         ズームレベル
  * @return CheckMapAreaResult
  */
- (CheckMapAreaResult)checkMapArea:(CLLocationCoordinate2D)coordinate zoom:(float)zoom;

@end

#endif
