//
//  ZMSMarker.h
//  ZDCMaps
//
//  Created by zdc on 2014/12/08.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#import "ZMSOverlay.h"

@class ZMSMarkerLayer;
@class UIImage;

/**
 * 地図上のある特定の位置を表すアイコン
 *
 * マーカーのアイコンは地図上の向きには依存せず端末の向きに合わせて描画される
 */
@interface ZMSMarker :  ZMSOverlay

/**
 * マーカーの位置
 */
@property(nonatomic, assign) CLLocationCoordinate2D position;

/**
 * マーカーが選択された時に情報ウィンドウの中にタイトルの下に表示されるスニペットテキスト
 */
@property(nonatomic, copy) NSString *Snipett;

/**
 * 任意のマーカー用のマーカー画像
 *
 * 未定義の場合は、デフォルトのマーカーが表示される
 */
@property(nonatomic, strong) UIImage *icon;

/**
 * アイコンの基準点
 *
 * [0.0, 1.0] x [0.0, 1.0] 左上が原点
 */
@property(nonatomic, assign) CGPoint groundAnchor;

/**
 * 情報ウィンドウの基準点
 *
 * 座標系は groundAnchor と同一
 */
@property(nonatomic, assign) CGPoint infoWindowAnchor;

/**
 * 基準点を中心に時計回りに角度を指定して回転
 *
 * 回転軸はマーカーに対して垂直方向
 */
@property(nonatomic, assign) CLLocationDegrees rotation;

/**
 * マーカーの透過をセット
 *
 * 0.0 完全に透過 - 1.0 不透過
 */
@property(nonatomic, assign) float opacity;

/**
 * ユーザデータ
 */
@property(nonatomic, strong) id userData;

/**
 * デフォルトマーカーの簡易ファクトリメソッド
 *
 * @param position CLLocationCoordinate2D型の緯度経度
 */
+ (instancetype)markerWithPosition:(CLLocationCoordinate2D)position;

@end
