//
//  ZMSMutablePath.h
//  ZDCMaps
//
//  Created by zdc on 2016/01/29.
//  Copyright (c) 2016年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#import "ZMSPath.h"

#import <CoreLocation/CoreLocation.h>
#import <Foundation/Foundation.h>

/**
 * ZMSMutablePathは動的にCLLocationCoordinate2Dの点列を変更可能なオブジェクト
 * 全座標は有効でなければいけない
 * ZMSMutablePathはZMSPathの座標変更可能バージョン
 */
@interface ZMSMutablePath : ZMSPath

/**
 * 点列に頂点座標を追加する
 * @param coord ポリラインの座標（緯度経度）
 */
- (void)addCoordinate:(CLLocationCoordinate2D)coord;

/** 
 * 座標点列に入力された緯度経度(度)によってCLLocationCoordinate2Dを追加する
 * @param latitude ポリラインに追加する座標の緯度
 * @param longitude ポリラインに追加する座標の経度
 */
- (void)addLatitude:(CLLocationDegrees)latitude longitude:(CLLocationDegrees)longitude;

/**
 * 指定した位置(index)に頂点座標を新規に挿入する
 * @param coord 挿入する座標の緯度経度
 * @param index 挿入するラインのインデックス
 */
- (void)insertCoordinate:(CLLocationCoordinate2D)coord atIndex:(NSUInteger)index;

/**
 * 指定した位置(index)の頂点座標を置き換える
 * @param index 置き換え対象のライン座標のインデックス
 * @param coord 置き換える座標の緯度経度
 */
- (void)replaceCoordinateAtIndex:(NSUInteger)index withCoordinate:(CLLocationCoordinate2D)coord;

/**
 * 指定した位置の頂点座標を削除する
 * @param index 削除する座標のインデックス
 */
- (void)removeCoordinateAtIndex:(NSUInteger)index;

/**
 * リストの末尾の座標を削除する
 */
- (void)removeLastCoordinate;

/**
 * リストの全ての座標を削除する
 */
- (void)removeAllCoordinates;

@end
