//
//  ZMSProjection.h
//  ZDCMaps
//
//  Created by zdc on 2014/12/08.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <CoreLocation/CoreLocation.h>

@class ZMSMapView;

// tilt時にfarが関連する
typedef struct {
    CLLocationCoordinate2D nearLeft;
    CLLocationCoordinate2D nearRight;
    CLLocationCoordinate2D farLeft;
    CLLocationCoordinate2D farRight;
} ZMSVisibleRegion;

/**
 * 緯度経度(CLLocationCoordinate2D)と地図のViewの座標（CGPoint）との相互射影を定義する
 *
 * このクラスは直接インスタンス化はできない代わりにZMSMapView経由で利用することができる
 */
@interface ZMSProjection : NSObject

/**
 * 緯度経度を地図のビュー上の座標に変換し返却する
 *
 * @param coordinate CLLocationCoordinate2D型の緯度経度座標
 * @return CGPoint スクリーン座標
 */
- (CGPoint)pointForCoordinate:(CLLocationCoordinate2D)coordinate;

/**
 * 地図上の点座標を緯度経度に変換し返却する
 *
 * @param point 任意のスクリーン座標
 * @return CLLocationCoordinate2D 緯度経度
 */
- (CLLocationCoordinate2D)coordinateForPoints:(CGPoint)point;


- (instancetype)init __attribute__((unavailable("init is not available")));

@end
