//
//  ZMSUISettings.h
//  ZDCMaps
//
//  Created by zdc on 2014/12/08.
//  Copyright (c) 2014年 ZENRIN DataCom Co., LTD.. All rights reserved.
//

#ifndef ZDCMaps_ZMSUISettings_h
#define ZDCMaps_ZMSUISettings_h

#import <CoreGraphics/CoreGraphics.h>
#import <UIKit/UIKit.h>

/**
 * ZMSMapViewのユーザーインターフェースを設定する
 */
@interface ZMSUISettings : NSObject

/**
 * 全てのジェスチャに対して、有効・無効をセットする
 */
- (void)setAllGesturesEnabled: (BOOL) enabled;

#pragma mark - ZDCMaps Original

/**
 * スクロールジェスチャの有効・無効設定用プロパティ
 * 有効な場合はカメラをパンするためにドラッグすることができる
 * このプロパティはソースコードによるカメラの動きを制限することはない
 */
@property(nonatomic, assign) BOOL scrollGestures;

/**
 * ズームジェスチャの有効・無効設定用プロパティ
 * 有効な場合ダブルタップ・2本指タップやピンチによるカメラの拡縮が可能となる
 */
@property(nonatomic, assign) BOOL zoomGestures;

/**
 * チルトジェスチャの有効・無効設定用プロパティ
 * 有効な場合は、2本指の垂直方向の上下スワイプによってカメラのチルトが可能となる
 */
@property(nonatomic, assign) BOOL tiltGestures;

/**
 * 回転ジェスチャの有効・無効設定用プロパティ
 * 有効な場合は、ユーザーは2本指による回転ジェスチャによってカメラを回転させることが可能である
 */
@property(nonatomic, assign) BOOL rotateGestures;

/**
 *  コンパスボタンの有効・無効設定プロパティ
 */
@property(nonatomic, assign) BOOL compassButton;

@property(nonatomic, assign) BOOL indoorEnabled;

/**
 * 現在地ボタンの有効・無効設定プロパティ
 * ユーザーによって現在地ボタンがタップされたとき、地図の中心が
 * 現在地となる
 */
@property(nonatomic, assign) BOOL myLocationButton;


/**
 * スケールバーの表示切り替え
 */
@property (nonatomic, assign) BOOL scaleBar;


/**
 * スケールバーの描画位置
 */
@property (nonatomic, assign) CGPoint scaleBarPad;

/**
 * スケールバーの基準位置
 * 0: 左上
 * 1: 右上
 * 2: 右下
 * 3: 左下
 */
@property (nonatomic, assign) NSInteger scaleBarCorner;

/**
 * コンパスの描画位置
 */
@property (nonatomic, assign) CGPoint CompassButtonPad;

/**
 * コンパスの基準位置
 * 0: 左上
 * 1: 右上
 * 2: 右下
 * 3: 左下
 */
@property (nonatomic, assign) NSInteger CompassButtonCorner;

/**
 * 現在地ボタンの描画位置
 */
@property (nonatomic, assign) CGPoint MyLocationButtonPad;

/**
 * 現在地ボタンの基準位置
 * 0: 左上
 * 1: 右上
 * 2: 右下
 * 3: 左下
 */
@property (nonatomic, assign) NSInteger MyLocationButtonCorner;

@property(nonatomic, assign) BOOL indoorPicker;

/*
 * 屋内地図階層選択ボタンの基準位置
 * 0: 左上
 * 1: 右上
 * 2: 右下
 * 3: 左下
 */
@property(nonatomic, assign) NSInteger indoorPickerCorner;

/*
 * 屋内地図階層選択ボタンの描画位置
 */
@property (nonatomic, assign) CGPoint indoorPickerPad;

/**
 * 現在地マーカーの画像変更用
 */
@property (nonatomic, strong) UIImage * myLocationMarker;

/**
 * ボタンデザインタイプ（現在地ボタン、現在地マーカー、コンパスボタン）
 * デザインタイプは[ 0〜2 ]
 */
@property ( nonatomic, assign ) NSInteger buttonType;


// deprecated
@property(nonatomic, assign) BOOL cacheEnabled __attribute__ ((deprecated));

// deparecated
@property(nonatomic, assign) NSUInteger cacheSize __attribute__ ((deprecated));

@end

#endif
